@@ -1,15 +1,5 @@
-# Copyright 2010-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License").
-# You may not use this file except in compliance with the License.
-# A copy of the License is located at
-#
-#  http://aws.amazon.com/apache2.0
-#
-# or in the "license" file accompanying this file. This file is distributed
-# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
-# express or implied. See the License for the specific language governing
-# permissions and limitations under the License.
+# Copyright Amazon.com, Inc. or its affiliates.  All rights reserved.
+# SPDX-License-Identifier: Apache-2.0.
 
 # This file is generated
 
@@ -665,13 +655,36 @@ class IotShadowClient(awsiot.MqttServiceClient):
             payload_to_class_fn=ErrorResponse.from_payload)
 
 class DeleteNamedShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'shadow_name', 'thing_name']
 
-    def __init__(self, client_token=None, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[str]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a DeleteNamedShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -681,20 +694,69 @@ class DeleteNamedShadowRequest(awsiot.ModeledClass):
         return payload
 
 class DeleteNamedShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['shadow_name', 'thing_name']
 
-    def __init__(self, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a DeleteNamedShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
 class DeleteShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'thing_name']
 
-    def __init__(self, client_token=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a DeleteShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        if len(args) == 1:
+            # if one positional parameter was passed, it must be the thing_name because it is
+            # a required parameter
+            setattr(self, 'thing_name', args[0])
+        elif len(args) == 2:
+            # if two parameters were passed, it must be the case that they are in the order
+            # of client_token, thing_name; nothing else could have ever worked
+            setattr(self, 'client_token', args[0])
+            setattr(self, 'thing_name', args[1])
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -704,13 +766,36 @@ class DeleteShadowRequest(awsiot.ModeledClass):
         return payload
 
 class DeleteShadowResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *timestamp* (``datetime.datetime``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'timestamp', 'version']
 
-    def __init__(self, client_token=None, timestamp=None, version=None):
-        # type: (typing.Optional[str], typing.Optional[datetime.datetime], typing.Optional[int]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a DeleteShadowResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *timestamp* (``datetime.datetime``)
+            * *version* (``int``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.timestamp = kwargs.get('timestamp')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['timestamp', 'version'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -728,21 +813,65 @@ class DeleteShadowResponse(awsiot.ModeledClass):
         return new
 
 class DeleteShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['thing_name']
 
-    def __init__(self, thing_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a DeleteShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *thing_name* (``str``)
+        """
+
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['thing_name'], args):
+            setattr(self, key, val)
 
 class ErrorResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *code* (``int``)
+        * *message* (``str``)
+        * *timestamp* (``datetime.datetime``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'code', 'message', 'timestamp']
 
-    def __init__(self, client_token=None, code=None, message=None, timestamp=None):
-        # type: (typing.Optional[str], typing.Optional[int], typing.Optional[str], typing.Optional[datetime.datetime]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.code = code # type: typing.Optional[int]
-        self.message = message # type: typing.Optional[str]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ErrorResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *code* (``int``)
+            * *message* (``str``)
+            * *timestamp* (``datetime.datetime``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.code = kwargs.get('code')
+        self.message = kwargs.get('message')
+        self.timestamp = kwargs.get('timestamp')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'code', 'message', 'timestamp'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -763,13 +892,36 @@ class ErrorResponse(awsiot.ModeledClass):
         return new
 
 class GetNamedShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'shadow_name', 'thing_name']
 
-    def __init__(self, client_token=None, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[str]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a GetNamedShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -779,20 +931,69 @@ class GetNamedShadowRequest(awsiot.ModeledClass):
         return payload
 
 class GetNamedShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['shadow_name', 'thing_name']
 
-    def __init__(self, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a GetNamedShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
 class GetShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'thing_name']
 
-    def __init__(self, client_token=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a GetShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        if len(args) == 1:
+            # if one positional parameter was passed, it must be the thing_name because it is
+            # a required parameter
+            setattr(self, 'thing_name', args[0])
+        elif len(args) == 2:
+            # if two parameters were passed, it must be the case that they are in the order
+            # of client_token, thing_name; nothing else could have ever worked
+            setattr(self, 'client_token', args[0])
+            setattr(self, 'thing_name', args[1])
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -802,15 +1003,42 @@ class GetShadowRequest(awsiot.ModeledClass):
         return payload
 
 class GetShadowResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *metadata* (``ShadowMetadata``)
+        * *state* (``ShadowStateWithDelta``)
+        * *timestamp* (``datetime.datetime``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'metadata', 'state', 'timestamp', 'version']
 
-    def __init__(self, client_token=None, metadata=None, state=None, timestamp=None, version=None):
-        # type: (typing.Optional[str], typing.Optional[ShadowMetadata], typing.Optional[ShadowStateWithDelta], typing.Optional[datetime.datetime], typing.Optional[int]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.metadata = metadata # type: typing.Optional[ShadowMetadata]
-        self.state = state # type: typing.Optional[ShadowStateWithDelta]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a GetShadowResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *metadata* (``ShadowMetadata``)
+            * *state* (``ShadowStateWithDelta``)
+            * *timestamp* (``datetime.datetime``)
+            * *version* (``int``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.metadata = kwargs.get('metadata')
+        self.state = kwargs.get('state')
+        self.timestamp = kwargs.get('timestamp')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['metadata', 'state', 'timestamp', 'version'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -834,37 +1062,123 @@ class GetShadowResponse(awsiot.ModeledClass):
         return new
 
 class GetShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['thing_name']
 
-    def __init__(self, thing_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a GetShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *thing_name* (``str``)
+        """
+
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['thing_name'], args):
+            setattr(self, key, val)
 
 class NamedShadowDeltaUpdatedSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['shadow_name', 'thing_name']
 
-    def __init__(self, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a NamedShadowDeltaUpdatedSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
 class NamedShadowUpdatedSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['shadow_name', 'thing_name']
 
-    def __init__(self, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a NamedShadowUpdatedSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
 class ShadowDeltaUpdatedEvent(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *metadata* (``typing.Dict[str, typing.Any]``)
+        * *state* (``typing.Dict[str, typing.Any]``)
+        * *timestamp* (``datetime.datetime``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['metadata', 'state', 'timestamp', 'version']
 
-    def __init__(self, metadata=None, state=None, timestamp=None, version=None):
-        # type: (typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[datetime.datetime], typing.Optional[int]) -> None
-        self.metadata = metadata # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.state = state # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowDeltaUpdatedEvent instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *metadata* (``typing.Dict[str, typing.Any]``)
+            * *state* (``typing.Dict[str, typing.Any]``)
+            * *timestamp* (``datetime.datetime``)
+            * *version* (``int``)
+        """
+
+        self.metadata = kwargs.get('metadata')
+        self.state = kwargs.get('state')
+        self.timestamp = kwargs.get('timestamp')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['metadata', 'state', 'timestamp', 'version'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -885,19 +1199,59 @@ class ShadowDeltaUpdatedEvent(awsiot.ModeledClass):
         return new
 
 class ShadowDeltaUpdatedSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['thing_name']
 
-    def __init__(self, thing_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowDeltaUpdatedSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *thing_name* (``str``)
+        """
+
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['thing_name'], args):
+            setattr(self, key, val)
 
 class ShadowMetadata(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *desired* (``typing.Dict[str, typing.Any]``)
+        * *reported* (``typing.Dict[str, typing.Any]``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['desired', 'reported']
 
-    def __init__(self, desired=None, reported=None):
-        # type: (typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[typing.Dict[str, typing.Any]]) -> None
-        self.desired = desired # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.reported = reported # type: typing.Optional[typing.Dict[str, typing.Any]]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowMetadata instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *desired* (``typing.Dict[str, typing.Any]``)
+            * *reported* (``typing.Dict[str, typing.Any]``)
+        """
+
+        self.desired = kwargs.get('desired')
+        self.reported = kwargs.get('reported')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['desired', 'reported'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -912,12 +1266,33 @@ class ShadowMetadata(awsiot.ModeledClass):
         return new
 
 class ShadowState(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *desired* (``typing.Dict[str, typing.Any]``)
+        * *reported* (``typing.Dict[str, typing.Any]``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['desired', 'reported']
 
-    def __init__(self, desired=None, reported=None):
-        # type: (typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[typing.Dict[str, typing.Any]]) -> None
-        self.desired = desired # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.reported = reported # type: typing.Optional[typing.Dict[str, typing.Any]]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowState instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *desired* (``typing.Dict[str, typing.Any]``)
+            * *reported* (``typing.Dict[str, typing.Any]``)
+        """
+
+        self.desired = kwargs.get('desired')
+        self.reported = kwargs.get('reported')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['desired', 'reported'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -941,13 +1316,36 @@ class ShadowState(awsiot.ModeledClass):
         return payload
 
 class ShadowStateWithDelta(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *delta* (``typing.Dict[str, typing.Any]``)
+        * *desired* (``typing.Dict[str, typing.Any]``)
+        * *reported* (``typing.Dict[str, typing.Any]``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['delta', 'desired', 'reported']
 
-    def __init__(self, delta=None, desired=None, reported=None):
-        # type: (typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[typing.Dict[str, typing.Any]], typing.Optional[typing.Dict[str, typing.Any]]) -> None
-        self.delta = delta # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.desired = desired # type: typing.Optional[typing.Dict[str, typing.Any]]
-        self.reported = reported # type: typing.Optional[typing.Dict[str, typing.Any]]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowStateWithDelta instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *delta* (``typing.Dict[str, typing.Any]``)
+            * *desired* (``typing.Dict[str, typing.Any]``)
+            * *reported* (``typing.Dict[str, typing.Any]``)
+        """
+
+        self.delta = kwargs.get('delta')
+        self.desired = kwargs.get('desired')
+        self.reported = kwargs.get('reported')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['delta', 'desired', 'reported'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -965,13 +1363,36 @@ class ShadowStateWithDelta(awsiot.ModeledClass):
         return new
 
 class ShadowUpdatedEvent(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *current* (``ShadowUpdatedSnapshot``)
+        * *previous* (``ShadowUpdatedSnapshot``)
+        * *timestamp* (``datetime.datetime``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['current', 'previous', 'timestamp']
 
-    def __init__(self, current=None, previous=None, timestamp=None):
-        # type: (typing.Optional[ShadowUpdatedSnapshot], typing.Optional[ShadowUpdatedSnapshot], typing.Optional[datetime.datetime]) -> None
-        self.current = current # type: typing.Optional[ShadowUpdatedSnapshot]
-        self.previous = previous # type: typing.Optional[ShadowUpdatedSnapshot]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowUpdatedEvent instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *current* (``ShadowUpdatedSnapshot``)
+            * *previous* (``ShadowUpdatedSnapshot``)
+            * *timestamp* (``datetime.datetime``)
+        """
+
+        self.current = kwargs.get('current')
+        self.previous = kwargs.get('previous')
+        self.timestamp = kwargs.get('timestamp')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['current', 'previous', 'timestamp'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -989,13 +1410,36 @@ class ShadowUpdatedEvent(awsiot.ModeledClass):
         return new
 
 class ShadowUpdatedSnapshot(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *metadata* (``ShadowMetadata``)
+        * *state* (``ShadowState``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['metadata', 'state', 'version']
 
-    def __init__(self, metadata=None, state=None, version=None):
-        # type: (typing.Optional[ShadowMetadata], typing.Optional[ShadowState], typing.Optional[int]) -> None
-        self.metadata = metadata # type: typing.Optional[ShadowMetadata]
-        self.state = state # type: typing.Optional[ShadowState]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowUpdatedSnapshot instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *metadata* (``ShadowMetadata``)
+            * *state* (``ShadowState``)
+            * *version* (``int``)
+        """
+
+        self.metadata = kwargs.get('metadata')
+        self.state = kwargs.get('state')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['metadata', 'state', 'version'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -1013,22 +1457,68 @@ class ShadowUpdatedSnapshot(awsiot.ModeledClass):
         return new
 
 class ShadowUpdatedSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['thing_name']
 
-    def __init__(self, thing_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a ShadowUpdatedSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *thing_name* (``str``)
+        """
+
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['thing_name'], args):
+            setattr(self, key, val)
 
 class UpdateNamedShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *shadow_name* (``str``)
+        * *state* (``ShadowState``)
+        * *thing_name* (``str``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'shadow_name', 'state', 'thing_name', 'version']
 
-    def __init__(self, client_token=None, shadow_name=None, state=None, thing_name=None, version=None):
-        # type: (typing.Optional[str], typing.Optional[str], typing.Optional[ShadowState], typing.Optional[str], typing.Optional[int]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.state = state # type: typing.Optional[ShadowState]
-        self.thing_name = thing_name # type: typing.Optional[str]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a UpdateNamedShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *shadow_name* (``str``)
+            * *state* (``ShadowState``)
+            * *thing_name* (``str``)
+            * *version* (``int``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.shadow_name = kwargs.get('shadow_name')
+        self.state = kwargs.get('state')
+        self.thing_name = kwargs.get('thing_name')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'shadow_name', 'state', 'thing_name', 'version'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -1042,22 +1532,68 @@ class UpdateNamedShadowRequest(awsiot.ModeledClass):
         return payload
 
 class UpdateNamedShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *shadow_name* (``str``)
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['shadow_name', 'thing_name']
 
-    def __init__(self, shadow_name=None, thing_name=None):
-        # type: (typing.Optional[str], typing.Optional[str]) -> None
-        self.shadow_name = shadow_name # type: typing.Optional[str]
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a UpdateNamedShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *shadow_name* (``str``)
+            * *thing_name* (``str``)
+        """
+
+        self.shadow_name = kwargs.get('shadow_name')
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['shadow_name', 'thing_name'], args):
+            setattr(self, key, val)
 
 class UpdateShadowRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *state* (``ShadowState``)
+        * *thing_name* (``str``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'state', 'thing_name', 'version']
 
-    def __init__(self, client_token=None, state=None, thing_name=None, version=None):
-        # type: (typing.Optional[str], typing.Optional[ShadowState], typing.Optional[str], typing.Optional[int]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.state = state # type: typing.Optional[ShadowState]
-        self.thing_name = thing_name # type: typing.Optional[str]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a UpdateShadowRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *state* (``ShadowState``)
+            * *thing_name* (``str``)
+            * *version* (``int``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.state = kwargs.get('state')
+        self.thing_name = kwargs.get('thing_name')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'state', 'thing_name', 'version'], args):
+            setattr(self, key, val)
 
     def to_payload(self):
         # type: () -> typing.Dict[str, typing.Any]
@@ -1071,15 +1607,42 @@ class UpdateShadowRequest(awsiot.ModeledClass):
         return payload
 
 class UpdateShadowResponse(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *client_token* (``str``)
+        * *metadata* (``ShadowMetadata``)
+        * *state* (``ShadowState``)
+        * *timestamp* (``datetime.datetime``)
+        * *version* (``int``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['client_token', 'metadata', 'state', 'timestamp', 'version']
 
-    def __init__(self, client_token=None, metadata=None, state=None, timestamp=None, version=None):
-        # type: (typing.Optional[str], typing.Optional[ShadowMetadata], typing.Optional[ShadowState], typing.Optional[datetime.datetime], typing.Optional[int]) -> None
-        self.client_token = client_token # type: typing.Optional[str]
-        self.metadata = metadata # type: typing.Optional[ShadowMetadata]
-        self.state = state # type: typing.Optional[ShadowState]
-        self.timestamp = timestamp # type: typing.Optional[datetime.datetime]
-        self.version = version # type: typing.Optional[int]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a UpdateShadowResponse instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *client_token* (``str``)
+            * *metadata* (``ShadowMetadata``)
+            * *state* (``ShadowState``)
+            * *timestamp* (``datetime.datetime``)
+            * *version* (``int``)
+        """
+
+        self.client_token = kwargs.get('client_token')
+        self.metadata = kwargs.get('metadata')
+        self.state = kwargs.get('state')
+        self.timestamp = kwargs.get('timestamp')
+        self.version = kwargs.get('version')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['client_token', 'metadata', 'state', 'timestamp', 'version'], args):
+            setattr(self, key, val)
 
     @classmethod
     def from_payload(cls, payload):
@@ -1103,9 +1666,28 @@ class UpdateShadowResponse(awsiot.ModeledClass):
         return new
 
 class UpdateShadowSubscriptionRequest(awsiot.ModeledClass):
+    r"""
+    Attributes:
+        * *thing_name* (``str``)
+
+    All attributes are None by default, and may be set by keyword in the constructor.
+    """
+
     __slots__ = ['thing_name']
 
-    def __init__(self, thing_name=None):
-        # type: (typing.Optional[str]) -> None
-        self.thing_name = thing_name # type: typing.Optional[str]
+    def __init__(self, *args, **kwargs):
+        r"""Initializes a UpdateShadowSubscriptionRequest instance
+
+        :param \**kwargs:
+            See below
+
+        :Keyword Arguments:
+            * *thing_name* (``str``)
+        """
+
+        self.thing_name = kwargs.get('thing_name')
+
+        # for backwards compatibility, read any arguments that used to be accepted by position
+        for key, val in zip(['thing_name'], args):
+            setattr(self, key, val)
 
